summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopetecommandhandler.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit2bc1d72869b62af05ae4feafd878203b526da8c5 (patch)
tree2676903bb600bd9646644856e354940471ad84e2 /kopete/libkopete/kopetecommandhandler.h
parent937b2991d8e78166eea904c80ad04d34607017a4 (diff)
downloadtdenetwork-2bc1d72869b62af05ae4feafd878203b526da8c5.tar.gz
tdenetwork-2bc1d72869b62af05ae4feafd878203b526da8c5.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/libkopete/kopetecommandhandler.h')
-rw-r--r--kopete/libkopete/kopetecommandhandler.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/kopete/libkopete/kopetecommandhandler.h b/kopete/libkopete/kopetecommandhandler.h
index aeb93529..5ffa76bb 100644
--- a/kopete/libkopete/kopetecommandhandler.h
+++ b/kopete/libkopete/kopetecommandhandler.h
@@ -74,7 +74,7 @@ class KOPETE_EXPORT CommandHandler : public TQObject
* Kopete::CommandHandler). These commands can also be overridden by
* registering a new duplicate command.
*
* @param tqparent The plugin who owns this command
* @param command The command we want to handle, not including the '/'
* @param handlerSlot The slot used to handle the command. This slot must
* accept two parameters, a TQString of arguments, and a Kopete::ChatSession
@@ -86,14 +86,14 @@ class KOPETE_EXPORT CommandHandler : public TQObject
* @param cut a default keyboard shortcut
* @param pix icon name, the icon will be shown in menus
*/
- void registerCommand( TQObject *tqparent, const TQString &command, const char* handlerSlot,
+ void registerCommand( TQObject *parent, const TQString &command, const char* handlerSlot,
const TQString &help = TQString(), uint minArgs = 0, int maxArgs = -1,
const KShortcut &cut = 0, const TQString &pix = TQString() );
/**
* \brief Register a command alias.
*
* @param tqparent The plugin who owns this alias
* @param alias The command for the alias
* @param formatString This is the string that will be transformed into another
* command. The formatString should begin with an already existing command,
@@ -107,7 +107,7 @@ class KOPETE_EXPORT CommandHandler : public TQObject
* @param cut a default keyboard shortcut
* @param pix icon name, the icon will be shown in menus
*/
- void registerAlias( TQObject *tqparent,
+ void registerAlias( TQObject *parent,
const TQString &alias,
const TQString &formatString,
const TQString &help = TQString(),
@@ -124,19 +124,19 @@ class KOPETE_EXPORT CommandHandler : public TQObject
* This function should only be called in the case of a plugin which loads and
* unloads commands dynamically.
*
* @param tqparent The plugin who owns this command
* @param command The command to unload
*/
- void unregisterCommand( TQObject *tqparent, const TQString &command );
+ void unregisterCommand( TQObject *parent, const TQString &command );
/**
* \brief Unregister an alias.
*
* \see unregisterCommand( TQObject *tqparent, const TQString &command )
* @param tqparent The plugin who owns this alias
* @param alias The alais to unload
*/
- void unregisterAlias( TQObject *tqparent, const TQString &alias );
+ void unregisterAlias( TQObject *parent, const TQString &alias );
/**
* \brief Process a message to see if any commands should be handled
@@ -74,7 +74,7 @@ class KOPETE_EXPORT CommandHandler : public TQObject
* registering a new duplicate command.
*
- * @param tqparent The plugin who owns this command
+ * @param parent The plugin who owns this command
* @param command The command we want to handle, not including the '/'
* @param handlerSlot The slot used to handle the command. This slot must
@@ -86,14 +86,14 @@ class KOPETE_EXPORT CommandHandler : public TQObject
* \brief Register a command alias.
*
- * @param tqparent The plugin who owns this alias
+ * @param parent The plugin who owns this alias
* @param alias The command for the alias
* @param formatString This is the string that will be transformed into another
@@ -124,19 +124,19 @@ class KOPETE_EXPORT CommandHandler : public TQObject
* unloads commands dynamically.
*
- * @param tqparent The plugin who owns this command
+ * @param parent The plugin who owns this command
* @param command The command to unload
*/
@@ -124,19 +124,19 @@ class KOPETE_EXPORT CommandHandler : public TQObject
* \brief Unregister an alias.
*
- * \see unregisterCommand( TQObject *tqparent, const TQString &command )
- * @param tqparent The plugin who owns this alias
+ * \see unregisterCommand( TQObject *parent, const TQString &command )
+ * @param parent The plugin who owns this alias
* @param alias The alais to unload
*/